DestinyCharacterCustomization

Struct DestinyCharacterCustomization 

pub struct DestinyCharacterCustomization {
    pub personality: u32,
    pub face: u32,
    pub skin_color: u32,
    pub lip_color: u32,
    pub eye_color: u32,
    pub hair_colors: Option<Vec<u32>>,
    pub feature_colors: Option<Vec<u32>>,
    pub decal_color: u32,
    pub wear_helmet: bool,
    pub hair_index: i32,
    pub feature_index: i32,
    pub decal_index: i32,
}
Raw data about the customization options chosen for a character’s face and appearance. You can look up the relevant class/race/gender combo in DestinyCharacterCustomizationOptionDefinition for the character, and then look up these values within the CustomizationOptions found to pull some data about their choices. Warning: not all of that data is meaningful. Some data has useful icons. Others have nothing, and are only meant for 3D rendering purposes (which we sadly do not expose yet)

Fields

personality: u32face: u32skin_color: u32lip_color: u32eye_color: u32hair_colors: Option<Vec<u32>>feature_colors: Option<Vec<u32>>decal_color: u32wear_helmet: boolhair_index: i32feature_index: i32decal_index: i32