DestinyClassDefinition

Struct DestinyClassDefinition 

pub struct DestinyClassDefinition {
    pub class_type: DestinyClass,
    pub display_properties: Option<DestinyDisplayPropertiesDefinition>,
    pub gendered_class_names: Option<HashMap<DestinyGender, String>>,
    pub gendered_class_names_by_gender_hash: Option<HashMap<u32, String>>,
    pub mentor_vendor_hash: Option<u32>,
    pub hash: u32,
    pub index: i32,
    pub redacted: bool,
}
Defines a Character Class in Destiny 2. These are types of characters you can play, like Titan, Warlock, and Hunter.

Fields

class_type: DestinyClass

In Destiny 1, we added a convenience Enumeration for referring to classes. We’ve kept it, though mostly for posterity. This is the enum value for this definition’s class.

display_properties: Option<DestinyDisplayPropertiesDefinition>gendered_class_names: Option<HashMap<DestinyGender, String>>

A localized string referring to the singular form of the Class’s name when referred to in gendered form. Keyed by the DestinyGender.

gendered_class_names_by_gender_hash: Option<HashMap<u32, String>>mentor_vendor_hash: Option<u32>

Mentors don’t really mean anything anymore. Don’t expect this to be populated.

hash: u32

The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.

index: i32

The index of the entity as it was found in the investment tables.

redacted: bool

If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!