pub struct DestinyProgressionResetEntry {
pub season: i32,
pub resets: i32,
}Expand description
Represents a season and the number of resets you had in that season. We do not necessarily - even for progressions with resets - track it over all seasons. So be careful and check the season numbers being returned.
Fields
season: i32resets: i32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DestinyProgressionResetEntry
impl<'de> Deserialize<'de> for DestinyProgressionResetEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more